@@ -4,7 +4,7 @@ import { ConnectedProps, connect } from 'react-redux';
 import { config, reportInteraction } from '@grafana/runtime';
 import { DataQuery } from '@grafana/schema';
 import { Button, Dropdown, Menu, ToolbarButton } from '@grafana/ui';
-import { t } from '@grafana/ui/src/utils/i18n';
+import { t } from 'app/core/internationalization';
 import { useSelector } from 'app/types';
 
 import { changeDatasource } from './state/datasource';
@@ -27,7 +27,7 @@ interface ExploreRunQueryButtonProps {
 
 export type Props = ConnectedProps<typeof connector> & ExploreRunQueryButtonProps;
 
-/* 
+/*
 This component does not validate datasources before running them. Root datasource validation should happen outside this component and can pass in an undefined if invalid
 If query level validation is done and a query datasource is invalid, pass in disabled = true
 */
@@ -82,7 +82,7 @@ export function ExploreRunQueryButton({
       const buttonText = runQueryText(exploreId, rootDatasourceUid);
       return (
         <Button
-          variant="secondary"
+          variant={'primary'}
           aria-label={buttonText.translation}
           onClick={() => {
             runQuery(exploreId);
@@ -118,7 +118,14 @@ export function ExploreRunQueryButton({
 
       return (
         <Dropdown onVisibleChange={(state) => setOpenRunQueryButton(state)} placement="bottom-start" overlay={menu}>
-          <ToolbarButton aria-label="run query options" variant="canvas" isOpen={openRunQueryButton}>
+          <ToolbarButton
+            aria-label={t(
+              'explore.explore-run-query-button.run-button.aria-label-run-query-options',
+              'Run query options'
+            )}
+            variant="canvas"
+            isOpen={openRunQueryButton}
+          >
             {t('explore.run-query.run-query-button', 'Run query')}
           </ToolbarButton>
         </Dropdown>
